@@ -601,52 +601,59 @@ def map_quantiles_for_entry(feature_name, input_df, row):
     if str(load_feature).lower() == "nan":
         mapping.append("")
     else:
-        feature_df = input_df[input_df['feature_name'] == (feature_name + "_quantiles")]
+        try:
+            feature_df = input_df[input_df['feature_name'] == (feature_name + "_quantiles")]
 
-        # Check if in p0-p25 quadrant
-        if load_feature < feature_df.iloc[0]["p10"]:
-            mapping.append("p0-p10")
+            # Check if in p0-p25 quadrant
+            if load_feature < feature_df.iloc[0]["p10"]:
+                mapping.append("p0-p10")
 
-        # Check if in p10-p25 quadrant
-        if load_feature >= feature_df.iloc[0]["p10"]:
-            if load_feature < feature_df.iloc[0]["p25"]:
-                mapping.append("p10-p25")
-            elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
-                mapping.append("p10-p25")
-            elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p50"] and load_feature < feature_df.iloc[0]["p75"]:
-                mapping.append("p10-p25")
-            elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p25"] and load_feature < feature_df.iloc[0]["p50"]:
-                mapping.append("p10-p25")
+            # Check if in p10-p25 quadrant
+            if load_feature >= feature_df.iloc[0]["p10"]:
+                if load_feature < feature_df.iloc[0]["p25"]:
+                    mapping.append("p10-p25")
+                elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
+                    mapping.append("p10-p25")
+                elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p50"] and load_feature < feature_df.iloc[0]["p75"]:
+                    mapping.append("p10-p25")
+                elif feature_df.iloc[0]["p10"] == feature_df.iloc[0]["p25"] and load_feature < feature_df.iloc[0]["p50"]:
+                    mapping.append("p10-p25")
 
-        # Check if in p25-p50 quadrant
-        if load_feature >= feature_df.iloc[0]["p25"]:
-            if load_feature < feature_df.iloc[0]["p50"]:
-                mapping.append("p25-p50")
-            elif feature_df.iloc[0]["p25"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
-                mapping.append("p25-p50")
-            elif feature_df.iloc[0]["p25"] == feature_df.iloc[0]["p50"] and load_feature < feature_df.iloc[0]["p75"]:
-                mapping.append("p25-p50")
+            # Check if in p25-p50 quadrant
+            if load_feature >= feature_df.iloc[0]["p25"]:
+                if load_feature < feature_df.iloc[0]["p50"]:
+                    mapping.append("p25-p50")
+                elif feature_df.iloc[0]["p25"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
+                    mapping.append("p25-p50")
+                elif feature_df.iloc[0]["p25"] == feature_df.iloc[0]["p50"] and load_feature < feature_df.iloc[0]["p75"]:
+                    mapping.append("p25-p50")
 
-        # Check if in p50-p75 quadrant
-        if load_feature >= feature_df.iloc[0]["p50"]:
-            if load_feature < feature_df.iloc[0]["p75"]:
-                mapping.append("p50-p75")
-            elif feature_df.iloc[0]["p50"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
-                mapping.append("p50-p75")
+            # Check if in p50-p75 quadrant
+            if load_feature >= feature_df.iloc[0]["p50"]:
+                if load_feature < feature_df.iloc[0]["p75"]:
+                    mapping.append("p50-p75")
+                elif feature_df.iloc[0]["p50"] == feature_df.iloc[0]["p75"] and load_feature < feature_df.iloc[0]["p90"]:
+                    mapping.append("p50-p75")
 
-        # Check if in p75-p90 quadrant
-        if feature_df.iloc[0]["p75"] <= load_feature < feature_df.iloc[0]["p90"]:
-            mapping.append("p75-p90")
+            # Check if in p75-p90 quadrant
+            if feature_df.iloc[0]["p75"] <= load_feature < feature_df.iloc[0]["p90"]:
+                mapping.append("p75-p90")
 
-        # Check if in p90-p100 quadrant
-        if load_feature >= feature_df.iloc[0]["p90"]:
-            mapping.append("p90-p100")
+            # Check if in p90-p100 quadrant
+            if load_feature >= feature_df.iloc[0]["p90"]:
+                mapping.append("p90-p100")
+        except Exception:
+            mapping = ("")
 
     return mapping
 
 
 def get_p50_value(feature_name, quantile_df):
-    feature_df = quantile_df[quantile_df['feature_name'] == (feature_name + "_quantiles")]
+    try:
+        feature_df = quantile_df[quantile_df['feature_name'] == (feature_name + "_quantiles")]
+    except Exception:
+        return np.nan
+
     return feature_df.iloc[0]["p50"]
 
 
