@@ -84,6 +84,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Multi Label Binarizer Variables
         # Split out Equipment Types
         df["equipment_type_list"] = df["equipment_type_list"].str.split(pat=", ")
+        df.equipment_types_list.fillna(value=u'', inplace=True)
 
         # Equipment Types
         df["equipment_type_encoded"] = list(self.load_equipment_mlb.transform(df["equipment_type_list"]))
@@ -109,11 +110,13 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Pickup State
         state_lbe = self.state_transforms[0]
         state_ohe = self.state_transforms[1]
+        df.pickup_state.fillna(value=u'', inplace=True)
         start_state_encoded = state_lbe.transform(df['pickup_state'])
         df["pickup_state_encoded"] = list(state_ohe.transform(start_state_encoded.reshape(-1, 1)))
         df.drop("pickup_state", axis=1, inplace=True)
 
         # Dropoff State
+        df.dropoff_state.fillna(value=u'', inplace=True)
         end_state_encoded = state_lbe.transform(df['dropoff_state'])
         df["dropoff_state_encoded"] = list(state_ohe.transform(end_state_encoded.reshape(-1, 1)))
         df.drop("dropoff_state", axis=1, inplace=True)
@@ -121,11 +124,13 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Pickup City
         city_lbe = self.city_transforms[0]
         city_ohe = self.city_transforms[1]
+        df.pickup_city.fillna(value=u'', inplace=True)
         pickup_city_encoded = city_lbe.transform(df['pickup_city'])
         df["pickup_city_encoded"] = list(city_ohe.transform(pickup_city_encoded.reshape(-1, 1)))
         df.drop("pickup_city", axis=1, inplace=True)
 
         # Dropoff City
+        df.dropoff_city.fillna(value=u'', inplace=True)
         dropoff_city_encoded = city_lbe.transform(df['dropoff_city'])
         df["dropoff_city_encoded"] = list(city_ohe.transform(dropoff_city_encoded.reshape(-1, 1)))
         df.drop("dropoff_city", axis=1, inplace=True)
@@ -133,6 +138,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Source
         source_lbe = self.source_transforms[0]
         source_ohe = self.source_transforms[1]
+        df.source.fillna(value=u'', inplace=True)
         source_encoded = source_lbe.transform(df['source'])
         df["source_encoded"] = list(source_ohe.transform(source_encoded.reshape(-1, 1)))
         df.drop("source", axis=1, inplace=True)
@@ -140,6 +146,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         # Email
         email_lbe = self.email_transforms[0]
         email_ohe = self.email_transforms[1]
+        df.contact_email.fillna(value=u'', inplace=True)
         email_encoded = email_lbe.transform(df['contact_email'])
         df["email_encoded"] = list(email_ohe.transform(email_encoded.reshape(-1, 1)))
         df.drop("contact_email", axis=1, inplace=True)
